@@ -2,7 +2,7 @@
 
 ### see also: http://www.metafor-project.org/doku.php/analyses:berkey1995
 
-context("Checking analysis example berkey1995")
+context("Checking analysis example: berkey1995")
 
 ### load BCG dataset
 data(dat.bcg, package="metafor")
@@ -18,6 +18,8 @@ test_that("results are correct for the random-effects model.", {
 
    ### fit random-effects model using empirical Bayes method
    res.RE <- rma(yi, vi, data=dat, method="EB")
+   out <- capture.output(print(res.RE)) ### so that print.rma.uni() is run (at least once)
+   out <- capture.output(print(summary(res.RE))) ### so that print.summary.rma() is run (at least once)
 
    ### compare with results on page 408
    expect_equivalent(round(coef(res.RE),4), -0.5429)
