@@ -35,6 +35,8 @@ test_that("results for the normal-normal model are correct (measure=='PLO')", {
 
 test_that("results for the binomial-normal normal are correct (measure=='PLO')", {
 
+   skip_on_cran()
+
    res <- rma.glmm(measure="PLO", xi=ci, ni=n2i, data=dat)
 
    ### compare with results on page 3050 (Table II)
@@ -61,7 +63,7 @@ test_that("results for the binomial-normal normal are correct (measure=='PLO')",
 
 test_that("results for the normal-normal model are correct (measure=='OR')", {
 
-   res <- rma(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat, drop00=TRUE)
+   expect_warning(res <- rma(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat, drop00=TRUE))
 
    ### compare with results on page 3052 (Table III)
    expect_equivalent(round(coef(res), digits=3), -0.980)
@@ -78,7 +80,8 @@ test_that("results for the conditional logistic model with exact likelihood are
 
    skip_on_cran()
 
-   res <- rma.glmm(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat, model="CM.EL")
+   expect_warning(res <- rma.glmm(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat, model="CM.EL"))
+   out <- capture.output(print(res)) ### so that print.rma.glmm() is run (at least once)
 
    ### compare with results on page 3052 (Table III)
    expect_equivalent(round(coef(res), digits=3), -1.353)
@@ -93,7 +96,9 @@ test_that("results for the conditional logistic model with exact likelihood are
 
 test_that("results for the conditional logistic model with approximate likelihood are correct (measure=='OR')", {
 
-   res <- rma.glmm(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat, model="CM.AL")
+   skip_on_cran()
+
+   expect_warning(res <- rma.glmm(measure="OR", ai=ai, n1i=n1i, ci=ci, n2i=n2i, data=dat, model="CM.AL"))
 
    ### compare with results on page 3052 (Table III)
    expect_equivalent(round(coef(res), digits=3), -1.303)
@@ -143,6 +148,8 @@ test_that("results for the normal-normal model are correct (measure=='IRLN')", {
 
 test_that("results for the Poisson-normal model are correct (measure=='IRLN')", {
 
+   skip_on_cran()
+
    res <- rma.glmm(measure="IRLN", xi=x2i, ti=t2i, data=dat)
 
    ### compare with results on page 3054 (Table VII)
@@ -184,6 +191,8 @@ test_that("results for the normal-normal model are correct (measure=='IRR')", {
 
 test_that("results for the Poisson-normal model are correct (measure=='IRR')", {
 
+   skip_on_cran()
+
    res <- rma.glmm(measure="IRR", x1i=x1i, t1i=t1i, x2i=x2i, t2i=t2i, data=dat, model="CM.EL")
 
    ### compare with results on page 3055 (Table VIII)
